import { Button, Grid, Stack, Typography } from '@mui/material'
import { Fragment, useEffect } from 'react'
import PlaintextUpload from './Upload/PlaintextUpload'
import FileUpload from './Upload/FileUpload'
import { useDispatch, useSelector } from 'react-redux'
import { RootState } from '../redux/store'
import { clear, consumeErr as consumeError } from './trackingToolSlice'
import { showNotification } from '../Notification/notificationSlice'
import ClearIcon from '@mui/icons-material/Clear'
import GeoJsonExportButton from './Import/GeoJsonExportButton'
import ProcessedTextDisplay from './Controls/ProcessedTextDisplay'
import MapPointToggleables from './Controls/MapPointToggleables'
import GeoJsonImportDialog from './Import/GeoJsonImportDialog'
import Map from './Map/Map'

// Page with tracking tool
const TrackingTool = () => {
    const pathDto = useSelector(
        // Path response from the API
        (state: RootState) => state.trackingTool.pathDto
    )

    // Use path as flag for undefined or present
    const path = useSelector(
        (state: RootState) => state.trackingTool.displayedPath
    )

    // Consume any error
    const dispatch = useDispatch()
    const err = useSelector((state: RootState) => state.trackingTool.lastError)
    useEffect(() => {
        if (!err) {
            return
        }
        const error = `${err}`
        dispatch(consumeError())
        dispatch(
            showNotification({
                message: error,
                severity: 'error',
            })
        )
    }, [err, dispatch])

    return (
        <Fragment>
            <Typography variant="h3" sx={{ mb: 2 }} fontWeight="bold">
                Tracking Tool
            </Typography>

            <Grid container>
                <Grid item xs={12}>
                    {pathDto && pathDto?.foundCatalogItems?.length === 0 && (
                        <Typography
                            variant="body1"
                            sx={{ mb: 2 }}
                            fontWeight="500"
                            align="center"
                            color="error.main"
                        >
                            Looks like no path / catalog items match this query.
                        </Typography>
                    )}
                    <Stack
                        direction="row"
                        alignItems="flex-start"
                        spacing={2}
                        sx={{ mt: 1 }}
                    >
                        {!pathDto && (
                            <Fragment>
                                <Typography
                                    variant="h5"
                                    sx={{ mb: 2 }}
                                    fontWeight="500"
                                >
                                    Upload:
                                </Typography>
                                <PlaintextUpload />
                                <FileUpload />
                            </Fragment>
                        )}
                        {path && (
                            <Fragment>
                                <GeoJsonImportDialog />
                                <GeoJsonExportButton />
                            </Fragment>
                        )}
                    </Stack>

                    {pathDto && (
                        <Fragment>
                            <MapPointToggleables />
                            <Stack alignItems="flex-end">
                                <Button
                                    startIcon={<ClearIcon />}
                                    sx={{ mb: 1 }}
                                    variant="contained"
                                    onClick={() => dispatch(clear())}
                                >
                                    Clear Map
                                </Button>
                            </Stack>
                        </Fragment>
                    )}
                </Grid>

                <Grid
                    item
                    xs={12}
                    md={12}
                    style={{
                        minHeight: '60vh',
                        maxHeight: '100vh',
                        width: '100%',
                    }}
                >
                    <Map />
                </Grid>
                <Grid container sx={{ mt: 1, mb: 20 }} spacing={1}>
                    <Grid item xs={12} md={6}>
                        {/* <MapPointDraggableList /> */}
                    </Grid>
                    <Grid item xs={12} md={6}>
                        <ProcessedTextDisplay />
                    </Grid>
                </Grid>
            </Grid>
        </Fragment>
    )
}

export default TrackingTool
